@@ -7,8 +7,7 @@
 
 import smtplib
 import socket
-from flask import current_app, render_template, url_for
-from flask_mail import Message
+from flask import current_app, render_template
 
 def _render_email(filename, **kwargs):
     # Render subject
@@ -23,10 +22,17 @@ def _render_email(filename, **kwargs):
 
     return (subject, html_message, text_message)
 
-def _send_email(recipient, subject, html_message, text_message):
+def send_email(recipient, subject, html_message, text_message):
+    """ Send email from default sender to 'recipient' """
+
     class SendEmailError(Exception):
         pass
 
+    try:
+        from flask_mail import Message
+    except:
+        raise SendEmailError("Flask-Mail is missing. Please install Flask-Mail ('pip install Flask-Mail').")
+
     # Construct Flash-Mail message
     message = Message(subject,
             recipients=[recipient],
@@ -43,31 +49,28 @@ def _send_email(recipient, subject, html_message, text_message):
     except smtplib.SMTPAuthenticationError:
         raise SendEmailError('SMTP Authentication error: Check your MAIL_USERNAME and MAIL_PASSWORD settings.')
 
-def send_registered_email(email, user, token):
+def send_registered_email(email, user, confirm_email_link):
     # Verify certain conditions
     user_manager =  current_app.user_manager
     if not user_manager.enable_email: return
-    if not user_manager.send_registered_email: return
+    if not user_manager.send_registered_email and not user_manager.enable_confirm_email: return
     assert(email)
-    # Generate confirmation link
-    confirm_email_link = url_for('user.confirm_email', token=token, _external=True)
+
     # Render subject, html message and text message
     subject, html_message, text_message = _render_email(
             user_manager.registered_email_template,
             user=user, confirm_email_link=confirm_email_link)
-    # Send email message using Flask-Mail
-    _send_email(email, subject, html_message, text_message)
 
-def send_forgot_password_email(email, user, token):
+    # Send email message using Flask-Mail
+    user_manager.send_email_function(email, subject, html_message, text_message)
+
+def send_forgot_password_email(email, user, reset_password_link):
     # Verify certain conditions
     user_manager =  current_app.user_manager
     if not user_manager.enable_email: return
     assert user_manager.enable_forgot_password
     assert email
 
-    # Generate confirmation link
-    reset_password_link = url_for('user.reset_password', token=token, _external=True)
-
     # Render subject, html message and text message
     subject, html_message, text_message = _render_email(
             user_manager.forgot_password_email_template,
@@ -75,4 +78,4 @@ def send_forgot_password_email(email, user, token):
             reset_password_link=reset_password_link)
 
     # Send email message using Flask-Mail
-    _send_email(email, subject, html_message, text_message)
+    user_manager.send_email_function(email, subject, html_message, text_message)
