@@ -50,7 +50,11 @@ def confirm_email(token):
     # Prepare one-time system message
     flash(_('Your email has been confirmed. Please sign in.'), 'success')
 
-    return redirect(user_manager.login_url)
+    # Retrieve 'next' query parameter
+    next = request.args.get('next', '/')
+
+    # Redirect to the login page with the specified 'next' query parameter
+    return redirect(user_manager.login_url+'?next='+next)
 
 
 @login_required
@@ -286,7 +290,7 @@ def register():
 
         # Prepare one-time system message
         if user_manager.enable_confirm_email:
-            flash(_('A confirmation email has been sent to %(email)s. Open that email and follow the instructions to complete your registration.', email=email_address), 'success')
+            flash(_('A confirmation email has been sent to %(email)s with instructions to complete your registration.', email=email_address), 'success')
         else:
             flash(_('You have registered successfully. Please sign in.'), 'success')
 
@@ -361,7 +365,7 @@ def unauthenticated():
 
     # Redirect to USER_UNAUTHENTICATED_URL
     user_manager = current_app.user_manager
-    return redirect(user_manager.unauthenticated_url)
+    return redirect(user_manager.unauthenticated_url+'?next='+url)
 
 def unauthorized():
     """ Prepare a Flash message and redirect to USER_UNAUTHORIZED_URL"""
